==> elyra-0.8.0-py3-none-any.whl: package/lib/style/FileListStyle.js <==
import { style } from 'typestyle';
export const moveFileUpButtonStyle = style({
    backgroundImage: 'var(--jp-icon-move-file-up)'
});
export const moveFileDownButtonStyle = style({
    backgroundImage: 'var(--jp-icon-move-file-down)'
});
export const moveFileUpButtonSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-move-file-up-hover)'
});
export const moveFileDownButtonSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-move-file-down-hover)'
});
export const notebookFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-book)'
});
export const consoleFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-terminal)'
});
export const terminalFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-terminal)'
});
export const folderFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-directory)'
});
export const genericFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-file)'
});
export const yamlFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-yaml)'
});
export const markdownFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-markdown)'
});
export const imageFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-image)'
});
export const spreadsheetFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-spreadsheet)'
});
export const jsonFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-json)'
});
export const pythonFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-python)'
});
export const kernelFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-r)'
});
export const notebookFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-book-selected)'
});
export const consoleFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-terminal-selected)'
});
export const terminalFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-terminal-selected)'
});
export const folderFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-directory-selected)'
});
export const genericFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-file-selected)'
});
export const yamlFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-yaml-selected)'
});
export const markdownFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-markdown-selected)'
});
export const imageFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-image-selected)'
});
export const spreadsheetFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-spreadsheet-selected)'
});
export const jsonFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-json-selected)'
});
export const pythonFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-python-selected)'
});
export const kernelFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-r-selected)'
});
//# sourceMappingURL=FileListStyle.js.map

==> elyra-1.0.0rc2-py3-none-any.whl: package/lib/style/FileListStyle.js <==
import { style } from 'typestyle';
export const fileListWrapperClass = style({
    height: 'auto',
    minHeight: '150px',
    overflow: 'hidden',
    overflowY: 'auto'
});
export const notebookFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-notebook)'
});
export const folderFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-directory)'
});
export const genericFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-file)'
});
export const yamlFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-yaml)'
});
export const markdownFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-markdown)'
});
export const imageFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-image)'
});
export const spreadsheetFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-spreadsheet)'
});
export const jsonFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-json)'
});
export const pythonFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-python)'
});
export const kernelFileIconStyle = style({
    backgroundImage: 'var(--jp-icon-r)'
});
export const notebookFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-notebook-selected)'
});
export const folderFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-directory-selected)'
});
export const genericFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-file-selected)'
});
export const yamlFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-yaml-selected)'
});
export const markdownFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-markdown-selected)'
});
export const imageFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-image-selected)'
});
export const spreadsheetFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-spreadsheet-selected)'
});
export const jsonFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-json-selected)'
});
export const pythonFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-python-selected)'
});
export const kernelFileIconSelectedStyle = style({
    backgroundImage: 'var(--jp-icon-r-selected)'
});
//# sourceMappingURL=FileListStyle.js.map
